==> pegasus-merchandise-api-3.11.12-GS-20250206.060648-2-sources.jar: com/thebeastshop/pegasus/merchandise/vo/PcsSkuAttributesVO.java <==
package com.thebeastshop.pegasus.merchandise.vo;

import com.thebeastshop.common.utils.ObjectChangeLog;

import java.io.Serializable;
import java.util.Date;

/**
 * @BelongsProject: workspace
 * @BelongsPackage: com.thebeastshop.pegasus.merchandise.vo
 * @Author: Gary
 * @CreateTime: 2024-04-09  14:48
 * @Description: TODO
 * @Version: 1.0
 */
public class PcsSkuAttributesVO implements Serializable {
    private static final long serialVersionUID = 7586766190608683757L;
    private String skuCode;

    private String chineseProductName;

    private String chineseColorStyle;

    private String chineseSpecification;

    private String englishProductName;

    private String englishColorStyle;

    private String englishSpecification;

    private Date gmtCreate;

    private Date gmtUpdate;

    @ObjectChangeLog(name = "备注")
    private String remark;
    @ObjectChangeLog(name = "工艺描述")
    private String processDescription;

    public String getSkuCode() {
        return skuCode;
    }

    public void setSkuCode(String skuCode) {
        this.skuCode = skuCode == null ? null : skuCode.trim();
    }

    public String getChineseProductName() {
        return chineseProductName;
    }

    public void setChineseProductName(String chineseProductName) {
        this.chineseProductName = chineseProductName == null ? null : chineseProductName.trim();
    }

    public String getChineseColorStyle() {
        return chineseColorStyle;
    }

    public void setChineseColorStyle(String chineseColorStyle) {
        this.chineseColorStyle = chineseColorStyle == null ? null : chineseColorStyle.trim();
    }

    public String getChineseSpecification() {
        return chineseSpecification;
    }

    public void setChineseSpecification(String chineseSpecification) {
        this.chineseSpecification = chineseSpecification == null ? null : chineseSpecification.trim();
    }

    public String getEnglishProductName() {
        return englishProductName;
    }

    public void setEnglishProductName(String englishProductName) {
        this.englishProductName = englishProductName == null ? null : englishProductName.trim();
    }

    public String getEnglishColorStyle() {
        return englishColorStyle;
    }

    public void setEnglishColorStyle(String englishColorStyle) {
        this.englishColorStyle = englishColorStyle == null ? null : englishColorStyle.trim();
    }

    public String getEnglishSpecification() {
        return englishSpecification;
    }

    public void setEnglishSpecification(String englishSpecification) {
        this.englishSpecification = englishSpecification == null ? null : englishSpecification.trim();
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtUpdate() {
        return gmtUpdate;
    }

    public void setGmtUpdate(Date gmtUpdate) {
        this.gmtUpdate = gmtUpdate;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark == null ? null : remark.trim();
    }

    public String getProcessDescription() {
        return processDescription;
    }

    public void setProcessDescription(String processDescription) {
        this.processDescription = processDescription == null ? null : processDescription.trim();
    }
}

==> pegasus-merchandise-api-4.0.9-GS-20251009.064654-10-sources.jar: com/thebeastshop/pegasus/merchandise/vo/PcsSkuAttributesVO.java <==
package com.thebeastshop.pegasus.merchandise.vo;

import com.thebeastshop.common.utils.ObjectChangeLog;

import java.io.Serializable;
import java.util.Date;

/**
 * @BelongsProject: workspace
 * @BelongsPackage: com.thebeastshop.pegasus.merchandise.vo
 * @Author: Gary
 * @CreateTime: 2024-04-09  14:48
 * @Description: TODO
 * @Version: 1.0
 */
public class PcsSkuAttributesVO implements Serializable {
    private static final long serialVersionUID = -6144146286186756753L;

    private String skuCode;
    @ObjectChangeLog(name = "商品中文名")
    private String chineseProductName;
    @ObjectChangeLog(name = "中文款式")
    private String chineseColorStyle;
    @ObjectChangeLog(name = "中文颜色")
    private String chineseColor;
    @ObjectChangeLog(name = "中文规格属性")
    private String chineseSpecification;
    private String chineseFullName;
    @ObjectChangeLog(name = "sku英文名")
    private String englishProductName;
    @ObjectChangeLog(name = "英文款式")
    private String englishColorStyle;
    @ObjectChangeLog(name = "英文颜色")
    private String englishColor;
    @ObjectChangeLog(name = "英文规格属性")
    private String englishSpecification;

    private Date gmtCreate;

    private Date gmtUpdate;

    @ObjectChangeLog(name = "备注")
    private String remark;
    @ObjectChangeLog(name = "工艺描述")
    private String processDescription;


    public String getSkuCode() {
        return skuCode;
    }

    public void setSkuCode(String skuCode) {
        this.skuCode = skuCode == null ? null : skuCode.trim();
    }

    public String getChineseProductName() {
        return chineseProductName;
    }

    public void setChineseProductName(String chineseProductName) {
        this.chineseProductName = chineseProductName == null ? null : chineseProductName.trim();
    }

    public String getChineseColorStyle() {
        return chineseColorStyle;
    }

    public void setChineseColorStyle(String chineseColorStyle) {
        this.chineseColorStyle = chineseColorStyle == null ? null : chineseColorStyle.trim();
    }

    public String getChineseSpecification() {
        return chineseSpecification;
    }

    public void setChineseSpecification(String chineseSpecification) {
        this.chineseSpecification = chineseSpecification == null ? null : chineseSpecification.trim();
    }

    public String getEnglishProductName() {
        return englishProductName;
    }

    public void setEnglishProductName(String englishProductName) {
        this.englishProductName = englishProductName == null ? null : englishProductName.trim();
    }

    public String getEnglishColorStyle() {
        return englishColorStyle;
    }

    public void setEnglishColorStyle(String englishColorStyle) {
        this.englishColorStyle = englishColorStyle == null ? null : englishColorStyle.trim();
    }

    public String getEnglishSpecification() {
        return englishSpecification;
    }

    public void setEnglishSpecification(String englishSpecification) {
        this.englishSpecification = englishSpecification == null ? null : englishSpecification.trim();
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtUpdate() {
        return gmtUpdate;
    }

    public void setGmtUpdate(Date gmtUpdate) {
        this.gmtUpdate = gmtUpdate;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark == null ? null : remark.trim();
    }

    public String getProcessDescription() {
        return processDescription;
    }

    public void setProcessDescription(String processDescription) {
        this.processDescription = processDescription == null ? null : processDescription.trim();
    }

    public String getChineseFullName() {
        return chineseFullName;
    }

    public void setChineseFullName(String chineseFullName) {
        this.chineseFullName = chineseFullName;
    }

    public String getChineseColor() {
        return chineseColor;
    }

    public void setChineseColor(String chineseColor) {
        this.chineseColor = chineseColor;
    }

    public String getEnglishColor() {
        return englishColor;
    }

    public void setEnglishColor(String englishColor) {
        this.englishColor = englishColor;
    }
}
